# Feature selection for ML workflows
This python package will automate feature selection in ML projects.

In the coming weeks I will add a plethora of information describing the use of the package and the algorithms that are working under the hood.

For now we will settle for a simple Read me to get us started on 0.0.1. 

As a general description this package is intended for the use of novice users looking for general feature seleciton in an automated fashion. This will not replace your own featue analysis but can help users make a good first step eliminating redundant features and begin looking for strong signals in their feature columns. 

# TODO
[X] python3 -m pip install --upgrade build

[] python3 -m build

[] python3 -m pip install --upgrade twine

[] python3 -m twine upload --repository feature_selection dist/*
  -  You will be prompted for a username and password. For the username, use __token__. 
  
  - For the password, use the token value, including the pypi- prefix.
